@@ -23,25 +23,31 @@ import time
 from typing import Dict
 
 import autopep8
-from black import FileMode
-from black import format_str
 from jinja2 import Environment
 from jinja2 import PackageLoader
 from jupyter_core.paths import ENV_JUPYTER_PATH
 from kfp import Client as ArgoClient
 from kfp import compiler as kfp_argo_compiler
 from kfp import components as components
+from kfp.dsl import PipelineConf
 from kfp.aws import use_aws_secret  # noqa H306
 from kfp_server_api.exceptions import ApiException
-from kfp_tekton import compiler as kfp_tekton_compiler
-from kfp_tekton import TektonClient
+from kubernetes import client as k8s_client
 import requests
 from urllib3.exceptions import LocationValueError
 from urllib3.exceptions import MaxRetryError
+try:
+    from kfp_tekton import compiler as kfp_tekton_compiler
+    from kfp_tekton import TektonClient
+except ImportError:
+    # We may not have kfp-tekton available and that's okay!
+    kfp_tekton_compiler = None
+    TektonClient = None
 
 from elyra._version import __version__
 from elyra.kfp.operator import ExecuteFileOp
 from elyra.metadata.manager import MetadataManager
+from elyra.metadata.schema import SchemaFilter
 from elyra.pipeline.component_parser_kfp import KfpComponentParser
 from elyra.pipeline.pipeline import GenericOperation
 from elyra.pipeline.pipeline import Operation
@@ -92,6 +98,8 @@ class KfpPipelineProcessor(RuntimePipelineProcessor):
         api_password = runtime_configuration.metadata.get('api_password')
 
         engine = runtime_configuration.metadata.get('engine')
+        if engine == 'Tekton' and not TektonClient:
+            raise ValueError('kfp-tekton not installed. Please install using elyra[kfp-tekton] to use Tekton engine.')
 
         pipeline_name = pipeline.name
         try:
@@ -188,10 +196,17 @@ class KfpPipelineProcessor(RuntimePipelineProcessor):
                                                               pipeline_version=pipeline_version_name,
                                                               experiment_name=experiment_name,
                                                               cos_directory=cos_directory)
+                # collect pipeline configuration information
+                pipeline_conf = self._generate_pipeline_conf(pipeline)
+
                 if 'Tekton' == engine:
-                    kfp_tekton_compiler.TektonCompiler().compile(pipeline_function, pipeline_path)
+                    kfp_tekton_compiler.TektonCompiler().compile(pipeline_function,
+                                                                 pipeline_path,
+                                                                 pipeline_conf=pipeline_conf)
                 else:
-                    kfp_argo_compiler.Compiler().compile(pipeline_function, pipeline_path)
+                    kfp_argo_compiler.Compiler().compile(pipeline_function,
+                                                         pipeline_path,
+                                                         pipeline_conf=pipeline_conf)
             except Exception as ex:
                 if ex.__cause__:
                     raise RuntimeError(str(ex)) from ex
@@ -203,7 +218,10 @@ class KfpPipelineProcessor(RuntimePipelineProcessor):
             # Upload the compiled pipeline, create an experiment and run
 
             try:
-                description = f"Created with Elyra {__version__} pipeline editor using '{pipeline.source}'."
+                pipeline_description = pipeline.description
+                if pipeline_description is None:
+                    pipeline_description = f"Created with Elyra {__version__} pipeline editor "\
+                                           f"using `{pipeline.source}`."
                 t0 = time.time()
 
                 if pipeline_id is None:
@@ -212,7 +230,7 @@ class KfpPipelineProcessor(RuntimePipelineProcessor):
                     kfp_pipeline = \
                         client.upload_pipeline(pipeline_path,
                                                pipeline_name,
-                                               description)
+                                               pipeline_description)
                     pipeline_id = kfp_pipeline.id
                     version_id = None
                 else:
@@ -267,6 +285,7 @@ class KfpPipelineProcessor(RuntimePipelineProcessor):
         t0_all = time.time()
         timestamp = datetime.now().strftime("%m%d%H%M%S")
         pipeline_name = pipeline.name
+        pipeline_description = pipeline.description
         pipeline_version_name = f'{pipeline_name}-{timestamp}'
         # work around https://github.com/kubeflow/pipelines/issues/5172
         experiment_name = pipeline_name.lower()
@@ -289,6 +308,9 @@ class KfpPipelineProcessor(RuntimePipelineProcessor):
         kf_secured = runtime_configuration.metadata.get('api_username') is not None and \
             runtime_configuration.metadata.get('api_password') is not None
 
+        if engine == 'Tekton' and not TektonClient:
+            raise ValueError('kfp-tekton not installed. Please install using elyra[kfp-tekton] to use Tekton engine.')
+
         if os.path.exists(absolute_pipeline_export_path) and not overwrite:
             raise ValueError("File " + absolute_pipeline_export_path + " already exists.")
 
@@ -302,7 +324,7 @@ class KfpPipelineProcessor(RuntimePipelineProcessor):
                 pipeline_function = lambda: self._cc_pipeline(pipeline,
                                                               pipeline_name,
                                                               cos_directory=cos_directory)  # nopep8
-                if 'Tekton' == engine:
+                if engine == 'Tekton':
                     self.log.info("Compiling pipeline for Tekton engine")
                     kfp_tekton_compiler.TektonCompiler().compile(pipeline_function, absolute_pipeline_export_path)
                 else:
@@ -331,7 +353,8 @@ class KfpPipelineProcessor(RuntimePipelineProcessor):
                                                  cos_directory=cos_directory,
                                                  export=True)
 
-            description = f'Created with Elyra {__version__} pipeline editor using {pipeline.source}.'
+            if pipeline_description is None:
+                pipeline_description = f"Created with Elyra {__version__} pipeline editor using `{pipeline.source}`."
 
             if self.log.isEnabledFor(logging.DEBUG):
                 self.log.debug(f"Exporting pipeline {pipeline_name} with components: \n")
@@ -355,14 +378,16 @@ class KfpPipelineProcessor(RuntimePipelineProcessor):
                                             cos_secret=cos_secret,
                                             namespace=namespace,
                                             api_endpoint=api_endpoint,
-                                            pipeline_description=description,
+                                            pipeline_description=pipeline_description,
                                             writable_container_dir=self.WCD,
                                             kf_secured=kf_secured)
 
             # Write to Python file and fix formatting
             with open(absolute_pipeline_export_path, "w") as fh:
+                # Defer the import to postpone logger messages: https://github.com/psf/black/issues/2058
+                import black
                 autopep_output = autopep8.fix_code(python_output)
-                output_to_file = format_str(autopep_output, mode=FileMode())
+                output_to_file = black.format_str(autopep_output, mode=black.FileMode())
                 fh.write(output_to_file)
 
             self.log_pipeline_info(pipeline_name, "pipeline rendered", duration=(time.time() - t0_all))
@@ -508,7 +533,7 @@ class KfpPipelineProcessor(RuntimePipelineProcessor):
 
                     self.log.debug(f"Processing component parameter '{component_property.name}' "
                                    f"of type '{component_property.type}'")
-                    if component_property.type == "file":
+                    if component_property.data_type == "file":
                         filename = get_absolute_path(get_expanded_path(self.root_dir), property_value)
                         try:
                             with open(filename) as f:
@@ -517,19 +542,19 @@ class KfpPipelineProcessor(RuntimePipelineProcessor):
                             # If file can't be found locally, assume a remote file location was entered.
                             # This may cause the pipeline run to fail; the user must debug in this case.
                             pass
-                    elif component_property.type == 'dictionary':
+                    elif component_property.data_type == 'dictionary':
                         processed_value = self._process_dictionary_value(property_value)
                         operation.component_params[component_property.ref] = processed_value
-                    elif component_property.type == 'list':
+                    elif component_property.data_type == 'list':
                         processed_value = self._process_list_value(property_value)
                         operation.component_params[component_property.ref] = processed_value
 
-                # Get absolute path of component source
-                component_path = component.source
-                if component.source_type == "filename":
+                # Get absolute path to the location of the component definition
+                component_path = component.location
+                if component.location_type == "filename":
                     component_path = os.path.join(ENV_JUPYTER_PATH[0], 'components', component_path)
 
-                component_source = {component.source_type: component_path}
+                component_source = {component.location_type: component_path}
 
                 # Build component task factory
                 try:
@@ -566,6 +591,48 @@ class KfpPipelineProcessor(RuntimePipelineProcessor):
 
         return target_ops
 
+    def _generate_pipeline_conf(self, pipeline: dict) -> PipelineConf:
+        """
+        Returns a KFP pipeline configuration for this pipeline, which can be empty.
+
+        :param pipeline: pipeline dictionary
+        :type pipeline: dict
+        :return: https://kubeflow-pipelines.readthedocs.io/en/latest/source/kfp.dsl.html#kfp.dsl.PipelineConf
+        :rtype: kfp.dsl import PipelineConf
+        """
+
+        self.log.debug('Generating pipeline configuration ...')
+        pipeline_conf = PipelineConf()
+
+        #
+        # Gather input for container image pull secrets in support of private container image registries
+        # https://kubeflow-pipelines.readthedocs.io/en/latest/source/kfp.dsl.html#kfp.dsl.PipelineConf.set_image_pull_secrets
+        #
+        image_namespace = self._get_metadata_configuration(namespace=MetadataManager.NAMESPACE_RUNTIME_IMAGES)
+
+        # iterate through pipeline operations and create list of Kubernetes secret names
+        # that are associated with generic components
+        container_image_pull_secret_names = []
+        for operation in pipeline.operations.values():
+            if isinstance(operation, GenericOperation):
+                for image_instance in image_namespace:
+                    if image_instance.metadata['image_name'] == operation.runtime_image:
+                        if image_instance.metadata.get('pull_secret'):
+                            container_image_pull_secret_names.append(image_instance.metadata.get('pull_secret'))
+                        break
+
+        if len(container_image_pull_secret_names) > 0:
+            # de-duplicate the pull secret name list, create Kubernetes resource
+            # references and add them to the pipeline configuration
+            container_image_pull_secrets = []
+            for secret_name in list(set(container_image_pull_secret_names)):
+                container_image_pull_secrets.append(k8s_client.V1ObjectReference(name=secret_name))
+            pipeline_conf.set_image_pull_secrets(container_image_pull_secrets)
+            self.log.debug(f'Added {len(container_image_pull_secrets)}'
+                           ' image pull secret(s) to the pipeline configuration.')
+
+        return pipeline_conf
+
     @staticmethod
     def _sanitize_operation_name(name: str) -> str:
         """
@@ -637,3 +704,24 @@ class KfpPipelineProcessorResponse(PipelineProcessorResponse):
     @property
     def type(self):
         return self._type
+
+
+class KfpSchemaFilter(SchemaFilter):
+    """
+    This class exists to ensure that the KFP schema's engine metadata
+    appropriately reflects what is installed on the system.
+    """
+
+    def post_load(self, name: str, schema_json: Dict) -> Dict:
+        """Ensure tekton packages are present and remove engine from schema if not."""
+
+        filtered_schema = super().post_load(name, schema_json)
+
+        # If TektonClient package is missing, navigate to the engine property
+        # and remove 'tekton' entry if present and return updated result.
+        if not TektonClient:
+            engine_enum: list = filtered_schema['properties']['metadata']['properties']['engine']['enum']
+            if 'Tekton' in engine_enum:
+                engine_enum.remove('Tekton')
+                filtered_schema['properties']['metadata']['properties']['engine']['enum'] = engine_enum
+        return filtered_schema
