@@ -15,13 +15,13 @@
  */
 describe('Script Editor tests', () => {
   before(() => {
-    cy.openJupyterLab();
+    cy.resetJupyterLab();
   });
 
   after(() => {
     // delete files created for testing
-    cy.deleteFileByName('untitled.py');
-    cy.deleteFileByName('untitled.r');
+    cy.deleteFile('untitled.py');
+    cy.deleteFile('untitled.r');
 
     // Delete runtime configuration used for testing
     cy.exec('elyra-metadata remove runtimes --name=test_runtime', {
@@ -31,20 +31,20 @@ describe('Script Editor tests', () => {
 
   // Python Tests
   it('opens blank Python file from launcher', () => {
-    cy.get('[title="Create a new Python file"][tabindex="100"]').click();
+    cy.get(
+      '.jp-LauncherCard[data-category="Elyra"][title="Create a new Python file"]'
+    ).click();
     cy.get('.lm-TabBar-tab[data-type="document-title"]');
   });
 
   it('close editor', () => {
     cy.get('.lm-TabBar-tabCloseIcon:visible').click();
-    cy.deleteFileByName('untitled.py');
   });
 
   it('opens blank Python file from menu', () => {
-    cy.get(':nth-child(1) > .lm-MenuBar-itemLabel').click();
-    cy.get(
-      ':nth-child(2) > .lm-Menu-itemSubmenuIcon > svg > .jp-icon3 > path'
-    ).click();
+    cy.findByRole('menuitem', { name: /file/i }).click();
+    cy.findByText(/^new$/i).click();
+
     cy.get(
       '[data-command="script-editor:create-new-python-file"] > .lm-Menu-itemLabel'
     ).click();
@@ -58,19 +58,17 @@ describe('Script Editor tests', () => {
     cy.get('.elyra-ScriptEditor .jp-Toolbar select > option[value*=python]');
   });
 
-  it('click the Submit Script button should display dialog', () => {
-    // Open runtimes sidebar
-    cy.get('.jp-SideBar [title="Runtimes"]').click();
+  it('click the Run as Pipeline button should display dialog', () => {
     // Create runtime configuration
     cy.createRuntimeConfig();
     // Validate it is now available
-    cy.get('#elyra-metadata span.elyra-expandableContainer-name').contains(
-      'Test Runtime'
-    );
-    // Click Submit Script button
-    cy.contains('Submit Script').click();
+    cy.get('#elyra-metadata\\:runtimes').within(() => {
+      cy.findByText(/test runtime/i).should('exist');
+    });
+    // Click Run as Pipeline button
+    cy.contains('Run as Pipeline').click();
     // Check for expected dialog title
-    cy.get('.jp-Dialog-header').should('have.text', 'Submit script');
+    cy.get('.jp-Dialog-header').should('have.text', 'Run script as pipeline');
     // Dismiss  dialog
     cy.get('button.jp-mod-reject').click();
 
@@ -85,7 +83,9 @@ describe('Script Editor tests', () => {
 
   // R Tests
   it('opens blank R file from launcher', () => {
-    cy.get('[title="Create a new R file"][tabindex="100"]').click();
+    cy.get(
+      '.jp-LauncherCard[data-category="Elyra"][title="Create a new R file"]'
+    ).click();
     cy.get('.lm-TabBar-tab[data-type="document-title"]');
   });
 
@@ -94,10 +94,9 @@ describe('Script Editor tests', () => {
   });
 
   it('opens blank R file from menu', () => {
-    cy.get(':nth-child(1) > .lm-MenuBar-itemLabel').click();
-    cy.get(
-      ':nth-child(2) > .lm-Menu-itemSubmenuIcon > svg > .jp-icon3 > path'
-    ).click();
+    cy.findByRole('menuitem', { name: /file/i }).click();
+    cy.findByText(/^new$/i).click();
+
     cy.get(
       '[data-command="script-editor:create-new-r-file"] > .lm-Menu-itemLabel'
     ).click();
@@ -130,6 +129,6 @@ const checkToolbarContent = (): void => {
   // check select kernel dropdown exists
   cy.get('.elyra-ScriptEditor .jp-Toolbar select');
 
-  // check Submit Script button exists
-  cy.contains('Submit Script');
+  // check Run as Pipeline button exists
+  cy.contains('Run as Pipeline');
 };
